==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Teistega jagatud",
    "Shared with you" : "Sinuga jagatud",
    "Shared by link" : "Jagatud lingiga",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "No shared links" : "Jagatud linke pole",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server URL" : "Vigane serveri URL",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ebaõnnestus",
    "Share" : "Jaga",
    "No expiration date set" : "Aegumise kuupäeva pole määratud",
    "Shared by" : "Jagas",
    "Sharing" : "Jagamine",
    "File shares" : "Jagatud failid",
    "Downloaded via public link" : "Alla laetud avalikult lingilt",
    "Downloaded by {email}" : "Alla laetud {email} poolt",
    "{file} downloaded via public link" : "{file} laeti alla avaliku lingi kaudu",
    "{email} downloaded {file}" : "{email} laadis {file} alla",
    "Shared with group {group}" : "Jagatud grupiga {group}",
    "Removed share for group {group}" : "Eemaldas jagamise grupiga {group}",
    "{actor} shared with group {group}" : "{actor} jagas grupiga {group}",
    "{actor} removed share for group {group}" : "{actor} eemaldas jagamise grupiga {group}",
    "You shared {file} with group {group}" : "Sa jagasid faili {file} grupiga {group}",
    "You removed group {group} from {file}" : "Sa eemaldasid grupi {group} faili {file} jagamisest",
    "{actor} shared {file} with group {group}" : "{actor} jagas faili {file} grupiga {group}",
    "{actor} removed group {group} from {file}" : "{actor} eemaldas grupi {group} faili {file} jagamisest",
    "Shared as public link" : "Jaga avaliku lingina",
    "Removed public link" : "Avalik link on eemaldatud",
    "Public link expired" : "Avalik link aegus",
    "{actor} shared as public link" : "{actor} jagas avaliku lingina",
    "{actor} removed public link" : "{actor} eemaldas avaliku lingi",
    "Public link of {actor} expired" : "{actor} avalik link aegus",
    "You shared {file} as public link" : "Sa jagasid {file} avaliku lingina",
    "You removed public link for {file}" : "Sa eemaldasid {file} avaliku lingi",
    "Public link expired for {file}" : "{file} avalik link aegus",
    "{actor} shared {file} as public link" : "{actor} jagas {file} avaliku lingina",
    "{actor} removed public link for {file}" : "{actor} eemaldas {file} avaliku lingi",
    "Public link of {actor} for {file} expired" : " {actor} faili {file} avalik link aegus",
    "{user} accepted the remote share" : "{user} aksepteeris kaugjagamise",
    "{user} declined the remote share" : "{user} keeldus kaugjagamisest",
    "You received a new remote share {file} from {user}" : "Sa said uue kaugjagatud faili {file} kasutajalt {user}",
    "{user} accepted the remote share of {file}" : "{user} aksepteeris faili {file} kaugjagamise",
    "{user} declined the remote share of {file}" : "{user} keeldus faili {file} kaugjagamisest",
    "{user} unshared {file} from you" : "{user} lõpetas sinuga faili {file} jagamise",
    "Shared with {user}" : "Jagatud kasutajale {user}",
    "Removed share for {user}" : "Eemaldas jagamise kasutajaga {user}",
    "{actor} shared with {user}" : "{actor} jagas kasutajaga {user}",
    "{actor} removed share for {user}" : "{actor} eemaldas jagamise kasutajaga {user}",
    "Shared by {actor}" : "Jagatud kasutajalt {actor}",
    "{actor} removed share" : "{actor} eemaldas jagamise",
    "You shared {file} with {user}" : "Sa jagasid {file} kasutajaga {user}",
    "You removed {user} from {file}" : "Sa eemaldasid faili {file} jagamise kasutajaga {user} ",
    "{actor} shared {file} with {user}" : "{actor} jagas {file} kasutajaga {user}",
    "{actor} removed {user} from {file}" : "{actor} eemaldas {user} jagamise faililt {file}",
    "{actor} shared {file} with you" : "{actor} jagas singuga {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Fail või kaust mis on jagatud e-posti või avaliku lingiga  <strong>laeti alla</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fail või kaust jagati <strong>teisest serverist</strong>",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "Wrong share ID, share doesn't exist" : "Vale jagamise ID, sellist jagamist ei eksisteeri",
    "could not delete share" : "ei saanud jagamist eemaldada",
    "Could not delete share" : "Ei saanud jagamist eemaldada",
    "Please specify a file or folder path" : "Palun määra faili või kausta rada",
    "Wrong path, file/folder doesn't exist" : "Vale rada, faili/kausta ei leitud",
    "Could not create share" : "Ei saanud jagamist luua",
    "invalid permissions" : "valed õigused",
    "Please specify a valid user" : "Palun määra kehtiv kasutaja",
    "Group sharing is disabled by the administrator" : "Grupiga jagamine on administraatori poolt keelatud",
    "Please specify a valid group" : "Palun määra kehtiv grupp",
    "Public link sharing is disabled by the administrator" : "Avaliku lingiga jagamine on administraatori poolt keelatud",
    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadminie on võimalik ainult avalikult jagatud kaustades",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "%s jagamine ebaõnnestus sest server ei luba %s tüüpi jagamisi",
    "You cannot share to a Circle if the app is not enabled" : "Sa ei saa jagada Ringi kui see rakendus pole lubatud",
    "Please specify a valid circle" : "Palun määra kehtiv ring",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Not a directory" : "Ei ole kaust",
    "Could not lock path" : "Ei saanud rada lukustada",
    "Wrong or no update parameter given" : "Antud vale või aegunud parameeter",
    "Can't change permissions for public share links" : "Avalikult jagatud linkide õigusi muuta ei saa",
    "Cannot increase permissions" : "Ei saa õigusi suurendada",
    "shared by %s" : "jagas %s",
    "Download" : "Lae alla",
    "Direct link" : "Otsene link",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Share API is disabled" : "Jagamise API on keelatud",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Expiration date" : "Aegumise kuupäev",
    "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Download %s" : "Laadi alla %s",
    "Upload files to %s" : "Laadi failid %s",
    "Select or drop files" : "Vali või lohista failid",
    "Uploading files…" : "Failide üleslaadimine...",
    "Uploaded files:" : "Üleslaetud failid:",
    "{actor} removed you from {file}" : "{actor} eemaldas sind {file} jagamisest",
    "%s is publicly shared" : "%s on avalikult jagatud",
    "This share is password-protected" : "See jagamine on parooliga kaitstud",
    "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
    "Password" : "Parool"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/et_EE.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Teistega jagatud",
    "Shared with you" : "Sinuga jagatud",
    "Shared by link" : "Jagatud lingiga",
    "Nothing shared with you yet" : "Sinuga pole veel midagi jagatud",
    "Files and folders others share with you will show up here" : "Siin näidatakse faile ja kaustasid, mida teised on sulle jaganud",
    "Nothing shared yet" : "Midagi pole veel jagatud",
    "Files and folders you share will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa oled teistega jaganud",
    "No shared links" : "Jagatud linke pole",
    "Files and folders you share by link will show up here" : "Siin kuvatakse faile ja kaustasid, mida sa jagad lingiga",
    "Download" : "Lae alla",
    "You can upload into this folder" : "Sa saad sellesse kausta faile üles laadida",
    "No compatible server found at {remote}" : "Aadressil {remote} ei leitud ühilduvat serverit",
    "Invalid server URL" : "Vigane serveri URL",
    "Failed to add the public link to your Nextcloud" : "Avaliku lingi lisamine sinu Nextcloudi ebaõnnestus",
    "No expiration date set" : "Aegumise kuupäeva pole määratud",
    "Shared by" : "Jagas",
    "File shares" : "Jagatud failid",
    "Downloaded via public link" : "Alla laetud avalikult lingilt",
    "Downloaded by {email}" : "Alla laetud {email} poolt",
    "{file} downloaded via public link" : "{file} laeti alla avaliku lingi kaudu",
    "{email} downloaded {file}" : "{email} laadis {file} alla",
    "Shared with group {group}" : "Jagatud grupiga {group}",
    "Removed share for group {group}" : "Eemaldas jagamise grupiga {group}",
    "{actor} shared with group {group}" : "{actor} jagas grupiga {group}",
    "{actor} removed share for group {group}" : "{actor} eemaldas jagamise grupiga {group}",
    "You shared {file} with group {group}" : "Sa jagasid faili {file} grupiga {group}",
    "You removed group {group} from {file}" : "Sa eemaldasid grupi {group} faili {file} jagamisest",
    "{actor} shared {file} with group {group}" : "{actor} jagas faili {file} grupiga {group}",
    "{actor} removed group {group} from {file}" : "{actor} eemaldas grupi {group} faili {file} jagamisest",
    "Shared as public link" : "Jaga avaliku lingina",
    "Removed public link" : "Avalik link on eemaldatud",
    "Public link expired" : "Avalik link aegus",
    "{actor} shared as public link" : "{actor} jagas avaliku lingina",
    "{actor} removed public link" : "{actor} eemaldas avaliku lingi",
    "Public link of {actor} expired" : "{actor} avalik link aegus",
    "You shared {file} as public link" : "Sa jagasid {file} avaliku lingina",
    "You removed public link for {file}" : "Sa eemaldasid {file} avaliku lingi",
    "Public link expired for {file}" : "{file} avalik link aegus",
    "{actor} shared {file} as public link" : "{actor} jagas {file} avaliku lingina",
    "{actor} removed public link for {file}" : "{actor} eemaldas {file} avaliku lingi",
    "Public link of {actor} for {file} expired" : " {actor} faili {file} avalik link aegus",
    "{user} accepted the remote share" : "{user} aksepteeris kaugjagamise",
    "{user} declined the remote share" : "{user} keeldus kaugjagamisest",
    "You received a new remote share {file} from {user}" : "Sa said uue kaugjagatud faili {file} kasutajalt {user}",
    "{user} accepted the remote share of {file}" : "{user} aksepteeris faili {file} kaugjagamise",
    "{user} declined the remote share of {file}" : "{user} keeldus faili {file} kaugjagamisest",
    "{user} unshared {file} from you" : "{user} lõpetas sinuga faili {file} jagamise",
    "Shared with {user}" : "Jagatud kasutajale {user}",
    "Removed share for {user}" : "Eemaldas jagamise kasutajaga {user}",
    "{actor} shared with {user}" : "{actor} jagas kasutajaga {user}",
    "{actor} removed share for {user}" : "{actor} eemaldas jagamise kasutajaga {user}",
    "Shared by {actor}" : "Jagatud kasutajalt {actor}",
    "{actor} removed share" : "{actor} eemaldas jagamise",
    "You shared {file} with {user}" : "Sa jagasid {file} kasutajaga {user}",
    "You removed {user} from {file}" : "Sa eemaldasid faili {file} jagamise kasutajaga {user} ",
    "{actor} shared {file} with {user}" : "{actor} jagas {file} kasutajaga {user}",
    "{actor} removed {user} from {file}" : "{actor} eemaldas {user} jagamise faililt {file}",
    "{actor} shared {file} with you" : "{actor} jagas sinuga {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Fail või kaust mis on jagatud e-posti või avaliku lingiga  <strong>laeti alla</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Fail või kaust jagati <strong>teisest serverist</strong>",
    "A file or folder has been <strong>shared</strong>" : "Fail või kataloog on <strong>jagatud</strong>",
    "Wrong share ID, share doesn't exist" : "Vale jagamise ID, sellist jagamist ei eksisteeri",
    "Could not delete share" : "Ei saanud jagamist eemaldada",
    "Please specify a file or folder path" : "Palun määra faili või kausta rada",
    "Wrong path, file/folder doesn't exist" : "Vale rada, faili/kausta ei leitud",
    "Could not create share" : "Ei saanud jagamist luua",
    "invalid permissions" : "valed õigused",
    "Please specify a valid user" : "Palun määra kehtiv kasutaja",
    "Group sharing is disabled by the administrator" : "Grupiga jagamine on administraatori poolt keelatud",
    "Please specify a valid group" : "Palun määra kehtiv grupp",
    "Public link sharing is disabled by the administrator" : "Avaliku lingiga jagamine on administraatori poolt keelatud",
    "Public upload disabled by the administrator" : "Avalik üleslaadimine on administraatori poolt keelatud",
    "Public upload is only possible for publicly shared folders" : "Avalik üleslaadminie on võimalik ainult avalikult jagatud kaustades",
    "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "Sa ei saa jagada Ringi kui see rakendus pole lubatud",
    "Please specify a valid circle" : "Palun määra kehtiv ring",
    "Unknown share type" : "Tundmatu jagamise tüüp",
    "Not a directory" : "Ei ole kaust",
    "Could not lock path" : "Ei saanud rada lukustada",
    "Wrong or no update parameter given" : "Antud vale või aegunud parameeter",
    "Can't change permissions for public share links" : "Avalikult jagatud linkide õigusi muuta ei saa",
    "shared by %s" : "jagas %s",
    "Direct link" : "Otsene link",
    "Add to your Nextcloud" : "Lisa oma Nextcloudi",
    "Share API is disabled" : "Jagamise API on keelatud",
    "Sharing" : "Jagamine",
    "Share" : "Jaga",
    "No entries found in this folder" : "Selles kaustas ei leitud kirjeid",
    "Name" : "Nimi",
    "Share time" : "Jagamise aeg",
    "Expiration date" : "Aegumise kuupäev",
    "Sorry, this link doesn’t seem to work anymore." : "Vabandust, see link ei tundu enam toimivat.",
    "Reasons might be:" : "Põhjused võivad olla:",
    "the item was removed" : "üksus on eemaldatud",
    "the link expired" : "link on aegunud",
    "sharing is disabled" : "jagamine on peatatud",
    "For more info, please ask the person who sent this link." : "Täpsema info saamiseks palun pöördu lingi saatnud isiku poole.",
    "Download %s" : "Laadi alla %s",
    "Upload files to %s" : "Laadi failid %s",
    "Select or drop files" : "Vali või lohista failid",
    "Uploading files…" : "Failide üleslaadimine…",
    "Uploaded files:" : "Üleslaetud failid:",
    "could not delete share" : "ei saanud jagamist eemaldada"
},
"nplurals=2; plural=(n != 1);");
